# BMKG-Latest
This package will guide us to receive the latest Eartquake Information from BMKG Indonesia

## How it works?
This package is getting the latest data of Indonesia Earthquake by scrapping from [BMKG](https://www.bmkg.go.id/) 

BeautifulSoup4 and Requests pacakge are used to produce JSON-form output which is ready to use in web or mobile apps

# Author
Firdaus Wahyu Nugroho